@@ -137,7 +137,7 @@ void SettingsBase::initToolBar()
     configureAction->setText( i18n("Configure") );
     // Help after it
     initHelpMenu();
-    configureAction->setIcon(QIcon::fromTheme("application-menu"));
+    configureAction->setIcon(QIcon::fromTheme("settings-configure"));
 
     // Then a spacer so the search line-edit is kept separate
     spacerAction = new QWidgetAction( this );
@@ -192,6 +192,7 @@ void SettingsBase::initConfig()
         viewSelection.addButton( radioButton, possibleViews.values().indexOf(mode) );
     }
     configWidget.GbViewStyle->setLayout( configLayout );
+    configWidget.GbViewStyle->setVisible( possibleViews.count() > 1 );
     KWindowConfig::restoreWindowSize(configDialog->windowHandle(), KSharedConfig::openConfig()->group("ConfigDialog"));
     connect(configDialog, &KConfigDialog::accepted, this, &SettingsBase::configUpdated);
 }
