@@ -21,11 +21,11 @@
 #ifndef MODULE_VIEW_H
 #define MODULE_VIEW_H
 
+#include <KPageView>
 #include <QWidget>
 #include <QtCore/QModelIndex>
 #include "systemsettingsview_export.h"
 
-class MenuItem;
 class KAboutData;
 class KCModuleInfo;
 class KCModuleProxy;
@@ -91,6 +91,10 @@ public:
      */
     void closeModules();
 
+    void setFaceType(KPageView::FaceType type);
+
+    KPageView::FaceType faceType() const;
+
 public Q_SLOTS:
     /**
      * Loads the module specified by menuItem.\n
@@ -123,7 +127,7 @@ public Q_SLOTS:
     /**
      * Reimplemented for internal reasons.\n
      */
-    void keyPressEvent( QKeyEvent * event );
+    void keyPressEvent( QKeyEvent * event ) Q_DECL_OVERRIDE;
 
 private:
     bool resolveChanges( KCModuleProxy *currentProxy );
